<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-macOS-blue.svg?longCache=True)]()
[![](https://img.shields.io/badge/language-AppleScript-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install mac-finder
```

#### Scripts usage
command|`usage`
-|-
`finder` |`usage: finder command [args]`
`finder-comment` |`usage: finder-comment path [comment]`
`finder-exec` |`usage: finder-exec command [args ...]`
`finder-icon` |`usage: finder-icon path image`
`finder-reveal` |`usage: finder-reveal path`
`finder-selection` |`usage: finder-selection`

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>